==> jboss-eap-6.2.2-src.zip: jboss-eap-6.2-src/server/src/main/java/org/jboss/as/server/RuntimeExpressionResolver.java <==
/*
* JBoss, Home of Professional Open Source.
* Copyright 2011, Red Hat Middleware LLC, and individual contributors
* as indicated by the @author tags. See the copyright.txt file in the
* distribution for a full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.as.server;

import org.jboss.as.controller.ExpressionResolverImpl;
import org.jboss.as.controller.VaultReader;
import org.jboss.dmr.ModelNode;

/**
 *
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
public class RuntimeExpressionResolver extends ExpressionResolverImpl {
    private final VaultReader vaultReader;

    public RuntimeExpressionResolver(VaultReader vaultReader) {
        this.vaultReader = vaultReader;
    }

    @Override
    protected void resolvePluggableExpression(ModelNode node) {
        String expression = node.asString();
        if (expression.length() > 3) {
            expression = expression.substring(2, expression.length() -1);
            if (vaultReader != null && vaultReader.isVaultFormat(expression)) {
                node.set(vaultReader.retrieveFromVault(expression));
            }
        }
    }
}

==> jboss-eap-6.4.20-src.zip: jboss-eap-6.4-src/server/src/main/java/org/jboss/as/server/RuntimeExpressionResolver.java <==
/*
* JBoss, Home of Professional Open Source.
* Copyright 2011, Red Hat Middleware LLC, and individual contributors
* as indicated by the @author tags. See the copyright.txt file in the
* distribution for a full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.as.server;

import org.jboss.as.controller.ExpressionResolverImpl;
import org.jboss.as.controller.OperationFailedException;
import org.jboss.as.controller.VaultReader;
import org.jboss.as.controller.ControllerMessages;
import org.jboss.dmr.ModelNode;

/**
 *
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
public class RuntimeExpressionResolver extends ExpressionResolverImpl {
    private final VaultReader vaultReader;

    public RuntimeExpressionResolver(VaultReader vaultReader) {
        this.vaultReader = vaultReader;
    }

    @Override
    protected void resolvePluggableExpression(ModelNode node) throws OperationFailedException {
        String expression = node.asString();
        if (expression.length() > 3) {
            String vaultedData = expression.substring(2, expression.length() -1);
            if (vaultReader != null && vaultReader.isVaultFormat(vaultedData)) {
                try {
                    node.set(vaultReader.retrieveFromVault(vaultedData));
                } catch (VaultReader.NoSuchItemException nsie) {
                    throw ControllerMessages.MESSAGES.cannotResolveExpression(expression);
                }
            }
        }
    }
}
